import {
  maxColorValSelector,
  minColorValSelector,
  neutralColorValSelector,
  overlayOpacitySelector,
} from '@/redux/configuration/configuration.selectors';
import { useAppSelector } from '@/redux/hooks/useAppSelector';
import { getHexTricolorGradientColorWithAlpha } from '@/utils/convert/getHexTricolorGradientColorWithAlpha';
import { useCallback } from 'react';

export type GetHex3ColorGradientColorWithAlpha = (position: number) => string;

type UseTriColorLerpReturn = {
  getHex3ColorGradientColorWithAlpha: GetHex3ColorGradientColorWithAlpha;
};

export const useTriColorLerp = (): UseTriColorLerpReturn => {
  const minColorValHexString = useAppSelector(minColorValSelector) || '';
  const maxColorValHexString = useAppSelector(maxColorValSelector) || '';
  const neutralColorValHexString = useAppSelector(neutralColorValSelector) || '';
  const overlayOpacityValue = useAppSelector(overlayOpacitySelector) || '';

  const getHex3ColorGradientColorWithAlpha = useCallback(
    (position: number) =>
      getHexTricolorGradientColorWithAlpha({
        leftColor: minColorValHexString,
        middleColor: neutralColorValHexString,
        rightColor: maxColorValHexString,
        position,
        alpha: Number(overlayOpacityValue),
      }),
    [minColorValHexString, neutralColorValHexString, maxColorValHexString, overlayOpacityValue],
  );

  return { getHex3ColorGradientColorWithAlpha };
};
